GpgContext

Struct GpgContext 

pub struct GpgContext {
    pub config: GpgConfig,
    /* private fields */
}
A context for cryptographic operations.

Fields

config: GpgConfig

GPGME configuration manager.

Implementations

Source

impl GpgContext

pub fn new(config: GpgConfig) -> Result<Self>

Constructs a new instance of GpgContext.

pub fn apply_config(&mut self)

Applies the current configuration values to the context.

pub fn get_output_file( &self, key_type: KeyType, patterns: Vec<String>, ) -> Result<PathBuf>

Returns the configured file path.

output_dir is used for output directory.

pub fn get_key(&mut self, key_type: KeyType, key_id: String) -> Result<Key>

Returns the public/secret key with the specified ID.

pub fn get_keys( &mut self, key_type: KeyType, patterns: Option<Vec<String>>, detail_level: KeyDetail, ) -> Result<Vec<GpgKey>>

Returns a list of all public/secret keys matching one or more of the specified patterns.

pub fn get_all_keys( &mut self, detail_level: Option<KeyDetail>, ) -> Result<HashMap<KeyType, Vec<GpgKey>>>

Returns the all available keys and their types in a HashMap.

pub fn import_keys( &mut self, keys: Vec<String>, read_from_file: bool, ) -> Result<u32>

Adds the given keys to the keyring.

pub fn get_exported_keys( &mut self, key_type: KeyType, patterns: Option<Vec<String>>, ) -> Result<Vec<u8>>

Returns the exported public/secret keys matching one or more of the specified patterns.

pub fn export_keys( &mut self, key_type: KeyType, patterns: Option<Vec<String>>, ) -> Result<String>

Exports keys and saves them to the specified/default path.

pub fn send_key(&mut self, key_id: String) -> Result<String>

Sends the given key to the default keyserver.

pub fn delete_key(&mut self, key_type: KeyType, key_id: String) -> Result<()>

Deletes the specified public/secret key.

Searches the keyring for finding the specified key ID for deleting it.