EventHandler

Struct EventHandler 

pub struct EventHandler {
    pub key_input_disabled: Arc<AtomicBool>,
    /* private fields */
}
Basic event handler for terminal events.

Event types are handled in a common handler thread and returned to a receiver.

Fields

key_input_disabled: Arc<AtomicBool>

Is the key input disabled?

Implementations

Source

impl EventHandler

pub fn new(tick_rate: u64) -> Self

Constructs a new instance of EventHandler.

pub fn next(&self) -> Result<Event, RecvError>

Receive the next event from handler.

This function will always block the current thread if there is no data available and it’s possible for more data to be sent.

(Note that Tick event is frequently received depending on the tick rate.)