pub struct GpgContext {
pub config: GpgConfig,
/* private fields */
}Expand description
A context for cryptographic operations.
Fields
config: GpgConfigGPGME configuration manager.
Implementations
Sourceimpl GpgContext
impl GpgContext
Sourcepub fn apply_config(&mut self)
pub fn apply_config(&mut self)
Applies the current configuration values to the context.
Sourcepub fn get_output_file(
&self,
key_type: KeyType,
patterns: Vec<String>,
) -> Result<PathBuf>
pub fn get_output_file( &self, key_type: KeyType, patterns: Vec<String>, ) -> Result<PathBuf>
Returns the configured file path.
output_dir is used for output directory.
Sourcepub fn get_key(&mut self, key_type: KeyType, key_id: String) -> Result<Key>
pub fn get_key(&mut self, key_type: KeyType, key_id: String) -> Result<Key>
Returns the public/secret key with the specified ID.
Sourcepub fn get_keys(
&mut self,
key_type: KeyType,
patterns: Option<Vec<String>>,
detail_level: KeyDetail,
) -> Result<Vec<GpgKey>>
pub fn get_keys( &mut self, key_type: KeyType, patterns: Option<Vec<String>>, detail_level: KeyDetail, ) -> Result<Vec<GpgKey>>
Returns a list of all public/secret keys matching one or more of the specified patterns.
Sourcepub fn get_all_keys(
&mut self,
detail_level: Option<KeyDetail>,
) -> Result<HashMap<KeyType, Vec<GpgKey>>>
pub fn get_all_keys( &mut self, detail_level: Option<KeyDetail>, ) -> Result<HashMap<KeyType, Vec<GpgKey>>>
Returns the all available keys and their types in a HashMap.
Sourcepub fn import_keys(
&mut self,
keys: Vec<String>,
read_from_file: bool,
) -> Result<u32>
pub fn import_keys( &mut self, keys: Vec<String>, read_from_file: bool, ) -> Result<u32>
Adds the given keys to the keyring.
Sourcepub fn get_exported_keys(
&mut self,
key_type: KeyType,
patterns: Option<Vec<String>>,
) -> Result<Vec<u8>>
pub fn get_exported_keys( &mut self, key_type: KeyType, patterns: Option<Vec<String>>, ) -> Result<Vec<u8>>
Returns the exported public/secret keys matching one or more of the specified patterns.
Sourcepub fn export_keys(
&mut self,
key_type: KeyType,
patterns: Option<Vec<String>>,
) -> Result<String>
pub fn export_keys( &mut self, key_type: KeyType, patterns: Option<Vec<String>>, ) -> Result<String>
Exports keys and saves them to the specified/default path.